aboutsummaryrefslogtreecommitdiffstats
path: root/sli/common/src/test
diff options
context:
space:
mode:
authorDan Timoney <dtimoney@att.com>2017-07-27 16:32:20 -0400
committerDan Timoney <dtimoney@att.com>2017-08-01 10:42:39 -0400
commit32f16144e17d2df0831f14d9e65a83756a6ef844 (patch)
tree4f7c5f04c3e4216b1821648cc67b17720b34a8a8 /sli/common/src/test
parentc95543bf425024f5bd4a127422251b72e408ce2b (diff)
Refactor dblib
Changed openecomp references in dblib, filters and sli to onap. Note: these must be committed together to get a clean compile. Issue: CCSDK-11 Change-Id: Ibe0f64fb20f3ae9cdda2f7ea969ca722bbde0d15 Signed-off-by: Dan Timoney <dtimoney@att.com>
Diffstat (limited to 'sli/common/src/test')
-rw-r--r--sli/common/src/test/java/org/onap/ccsdk/sli/core/sli/SvcLogicContextTest.java (renamed from sli/common/src/test/java/org/openecomp/sdnc/sli/SvcLogicContextTest.java)9
-rw-r--r--sli/common/src/test/java/org/onap/ccsdk/sli/core/sli/SvcLogicExpressionParserTest.java (renamed from sli/common/src/test/java/org/openecomp/sdnc/sli/SvcLogicExpressionParserTest.java)13
-rw-r--r--sli/common/src/test/java/org/onap/ccsdk/sli/core/sli/SvcLogicParserTest.java (renamed from sli/common/src/test/java/org/openecomp/sdnc/sli/SvcLogicParserTest.java)17
-rw-r--r--sli/common/src/test/resources/EvcActivateSvcLogic_v100.xml5
-rw-r--r--sli/common/src/test/resources/EvcPortSvcLogic_v100.xml5
-rw-r--r--sli/common/src/test/resources/ReleasePortSvcLogic_v101.xml5
-rw-r--r--sli/common/src/test/resources/bad_neutron_logic_v11.xml5
-rw-r--r--sli/common/src/test/resources/mergetest.xml5
-rw-r--r--sli/common/src/test/resources/neutron_logic_v10.xml5
-rw-r--r--sli/common/src/test/resources/nonsense.xml5
-rw-r--r--sli/common/src/test/resources/simplelogger.properties5
-rw-r--r--sli/common/src/test/resources/svclogic.properties5
-rw-r--r--sli/common/src/test/resources/svclogic.sh5
13 files changed, 38 insertions, 51 deletions
diff --git a/sli/common/src/test/java/org/openecomp/sdnc/sli/SvcLogicContextTest.java b/sli/common/src/test/java/org/onap/ccsdk/sli/core/sli/SvcLogicContextTest.java
index 6e6656e8..123083a7 100644
--- a/sli/common/src/test/java/org/openecomp/sdnc/sli/SvcLogicContextTest.java
+++ b/sli/common/src/test/java/org/onap/ccsdk/sli/core/sli/SvcLogicContextTest.java
@@ -1,9 +1,8 @@
/*-
* ============LICENSE_START=======================================================
- * openECOMP : SDN-C
+ * ONAP : CCSDK
* ================================================================================
- * Copyright (C) 2017 AT&T Intellectual Property. All rights
- * reserved.
+ * Copyright (C) 2017 ONAP
* ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -19,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.sdnc.sli;
+package org.onap.ccsdk.sli.core.sli;
import java.io.BufferedReader;
import java.io.ByteArrayInputStream;
@@ -31,7 +30,7 @@ import java.util.Properties;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
-import org.openecomp.sdnc.sli.SvcLogicContext;
+import org.onap.ccsdk.sli.core.sli.SvcLogicContext;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.w3c.dom.Document;
diff --git a/sli/common/src/test/java/org/openecomp/sdnc/sli/SvcLogicExpressionParserTest.java b/sli/common/src/test/java/org/onap/ccsdk/sli/core/sli/SvcLogicExpressionParserTest.java
index d6503b60..543bb1be 100644
--- a/sli/common/src/test/java/org/openecomp/sdnc/sli/SvcLogicExpressionParserTest.java
+++ b/sli/common/src/test/java/org/onap/ccsdk/sli/core/sli/SvcLogicExpressionParserTest.java
@@ -1,9 +1,8 @@
/*-
* ============LICENSE_START=======================================================
- * openECOMP : SDN-C
+ * ONAP : CCSDK
* ================================================================================
- * Copyright (C) 2017 AT&T Intellectual Property. All rights
- * reserved.
+ * Copyright (C) 2017 ONAP
* ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -19,15 +18,15 @@
* ============LICENSE_END=========================================================
*/
-package org.openecomp.sdnc.sli;
+package org.onap.ccsdk.sli.core.sli;
import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
-import org.openecomp.sdnc.sli.SvcLogicExprListener;
-import org.openecomp.sdnc.sli.SvcLogicExpression;
-import org.openecomp.sdnc.sli.SvcLogicExpressionFactory;
+import org.onap.ccsdk.sli.core.sli.SvcLogicExprListener;
+import org.onap.ccsdk.sli.core.sli.SvcLogicExpression;
+import org.onap.ccsdk.sli.core.sli.SvcLogicExpressionFactory;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
diff --git a/sli/common/src/test/resources/EvcActivateSvcLogic_v100.xml b/sli/common/src/test/resources/EvcActivateSvcLogic_v100.xml
index 097078a8..308bda1e 100644
--- a/sli/common/src/test/resources/EvcActivateSvcLogic_v100.xml
+++ b/sli/common/src/test/resources/EvcActivateSvcLogic_v100.xml
@@ -1,10 +1,9 @@
<?xml version="1.0" encoding="UTF-8"?>
<!--
============LICENSE_START=======================================================
- openECOMP : SDN-C
+ ONAP : CCSDK
================================================================================
- Copyright (C) 2017 AT&T Intellectual Property. All rights
- reserved.
+ Copyright (C) 2017 ONAP
================================================================================
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
diff --git a/sli/common/src/test/resources/EvcPortSvcLogic_v100.xml b/sli/common/src/test/resources/EvcPortSvcLogic_v100.xml
index 08084420..8a9578bb 100644
--- a/sli/common/src/test/resources/EvcPortSvcLogic_v100.xml
+++ b/sli/common/src/test/resources/EvcPortSvcLogic_v100.xml
@@ -1,10 +1,9 @@
<?xml version="1.0" encoding="UTF-8"?>
<!--
============LICENSE_START=======================================================
- openECOMP : SDN-C
+ ONAP : CCSDK
================================================================================
- Copyright (C) 2017 AT&T Intellectual Property. All rights
- reserved.
+ Copyright (C) 2017 ONAP
================================================================================
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
diff --git a/sli/common/src/test/resources/ReleasePortSvcLogic_v101.xml b/sli/common/src/test/resources/ReleasePortSvcLogic_v101.xml
index 5a835b7b..1cc6274d 100644
--- a/sli/common/src/test/resources/ReleasePortSvcLogic_v101.xml
+++ b/sli/common/src/test/resources/ReleasePortSvcLogic_v101.xml
@@ -1,10 +1,9 @@
<?xml version="1.0" encoding="UTF-8"?>
<!--
============LICENSE_START=======================================================
- openECOMP : SDN-C
+ ONAP : CCSDK
================================================================================
- Copyright (C) 2017 AT&T Intellectual Property. All rights
- reserved.
+ Copyright (C) 2017 ONAP
================================================================================
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
diff --git a/sli/common/src/test/resources/bad_neutron_logic_v11.xml b/sli/common/src/test/resources/bad_neutron_logic_v11.xml
index 4e1e8d9b..f3455388 100644
--- a/sli/common/src/test/resources/bad_neutron_logic_v11.xml
+++ b/sli/common/src/test/resources/bad_neutron_logic_v11.xml
@@ -1,10 +1,9 @@
<?xml version="1.0" encoding="UTF-8"?>
<!--
============LICENSE_START=======================================================
- openECOMP : SDN-C
+ ONAP : CCSDK
================================================================================
- Copyright (C) 2017 AT&T Intellectual Property. All rights
- reserved.
+ Copyright (C) 2017 ONAP
================================================================================
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
diff --git a/sli/common/src/test/resources/mergetest.xml b/sli/common/src/test/resources/mergetest.xml
index 12e083c7..37874413 100644
--- a/sli/common/src/test/resources/mergetest.xml
+++ b/sli/common/src/test/resources/mergetest.xml
@@ -1,9 +1,8 @@
<!--
============LICENSE_START=======================================================
- openECOMP : SDN-C
+ ONAP : CCSDK
================================================================================
- Copyright (C) 2017 AT&T Intellectual Property. All rights
- reserved.
+ Copyright (C) 2017 ONAP
================================================================================
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
diff --git a/sli/common/src/test/resources/neutron_logic_v10.xml b/sli/common/src/test/resources/neutron_logic_v10.xml
index 9cd33127..730ebc21 100644
--- a/sli/common/src/test/resources/neutron_logic_v10.xml
+++ b/sli/common/src/test/resources/neutron_logic_v10.xml
@@ -1,10 +1,9 @@
<?xml version="1.0" encoding="UTF-8"?>
<!--
============LICENSE_START=======================================================
- openECOMP : SDN-C
+ ONAP : CCSDK
================================================================================
- Copyright (C) 2017 AT&T Intellectual Property. All rights
- reserved.
+ Copyright (C) 2017 ONAP
================================================================================
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
diff --git a/sli/common/src/test/resources/nonsense.xml b/sli/common/src/test/resources/nonsense.xml
index 61220825..fdcfa346 100644
--- a/sli/common/src/test/resources/nonsense.xml
+++ b/sli/common/src/test/resources/nonsense.xml
@@ -1,9 +1,8 @@
<!--
============LICENSE_START=======================================================
- openECOMP : SDN-C
+ ONAP : CCSDK
================================================================================
- Copyright (C) 2017 AT&T Intellectual Property. All rights
- reserved.
+ Copyright (C) 2017 ONAP
================================================================================
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
diff --git a/sli/common/src/test/resources/simplelogger.properties b/sli/common/src/test/resources/simplelogger.properties
index 6f70984c..d88e59eb 100644
--- a/sli/common/src/test/resources/simplelogger.properties
+++ b/sli/common/src/test/resources/simplelogger.properties
@@ -1,9 +1,8 @@
###
# ============LICENSE_START=======================================================
-# openECOMP : SDN-C
+# ONAP : CCSDK
# ================================================================================
-# Copyright (C) 2017 AT&T Intellectual Property. All rights
-# reserved.
+# Copyright (C) 2017 ONAP
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
diff --git a/sli/common/src/test/resources/svclogic.properties b/sli/common/src/test/resources/svclogic.properties
index fa33146e..fa7a2041 100644
--- a/sli/common/src/test/resources/svclogic.properties
+++ b/sli/common/src/test/resources/svclogic.properties
@@ -1,9 +1,8 @@
###
# ============LICENSE_START=======================================================
-# openECOMP : SDN-C
+# ONAP : CCSDK
# ================================================================================
-# Copyright (C) 2017 AT&T Intellectual Property. All rights
-# reserved.
+# Copyright (C) 2017 ONAP
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
diff --git a/sli/common/src/test/resources/svclogic.sh b/sli/common/src/test/resources/svclogic.sh
index 09f0637d..f6c6f4b6 100644
--- a/sli/common/src/test/resources/svclogic.sh
+++ b/sli/common/src/test/resources/svclogic.sh
@@ -2,10 +2,9 @@
###
# ============LICENSE_START=======================================================
-# openECOMP : SDN-C
+# ONAP : CCSDK
# ================================================================================
-# Copyright (C) 2017 AT&T Intellectual Property. All rights
-# reserved.
+# Copyright (C) 2017 ONAP
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
diff --git a/sli/common/src/test/java/org/openecomp/sdnc/sli/SvcLogicParserTest.java b/sli/common/src/test/java/org/onap/ccsdk/sli/core/sli/SvcLogicParserTest.java
index e8ff2fee..2da8dd4f 100644
--- a/sli/common/src/test/java/org/openecomp/sdnc/sli/SvcLogicParserTest.java
+++ b/sli/common/src/test/java/org/onap/ccsdk/sli/core/sli/SvcLogicParserTest.java
@@ -1,9 +1,8 @@
/*-
* ============LICENSE_START=======================================================
- * openECOMP : SDN-C
+ * ONAP : CCSDK
* ================================================================================
- * Copyright (C) 2017 AT&T Intellectual Property. All rights
- * reserved.
+ * Copyright (C) 2017 ONAP
* ================================================================================
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -22,7 +21,7 @@
/**
*
*/
-package org.openecomp.sdnc.sli;
+package org.onap.ccsdk.sli.core.sli;
import java.io.BufferedReader;
import java.io.InputStream;
@@ -30,10 +29,10 @@ import java.io.InputStreamReader;
import java.net.URL;
import java.util.LinkedList;
-import org.openecomp.sdnc.sli.SvcLogicParser;
-import org.openecomp.sdnc.sli.SvcLogicParserException;
-import org.openecomp.sdnc.sli.SvcLogicStore;
-import org.openecomp.sdnc.sli.SvcLogicStoreFactory;
+import org.onap.ccsdk.sli.core.sli.SvcLogicParser;
+import org.onap.ccsdk.sli.core.sli.SvcLogicParserException;
+import org.onap.ccsdk.sli.core.sli.SvcLogicStore;
+import org.onap.ccsdk.sli.core.sli.SvcLogicStoreFactory;
import junit.framework.TestCase;
@@ -44,7 +43,7 @@ import junit.framework.TestCase;
public class SvcLogicParserTest extends TestCase {
/**
* Test method for {@link org.openecomp.sdnc.sli.SvcLogicParser#parse(java.lang.String)}.
*/
@@ -44,7 +43,7 @@ import junit.framework.TestCase;
public class SvcLogicParserTest extends TestCase {
/**
- * Test method for {@link org.openecomp.sdnc.sli.SvcLogicParser#parse(java.lang.String)}.
+ * Test method for {@link org.onap.ccsdk.sli.core.sli.SvcLogicParser#parse(java.lang.String)}.
*/